@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Util::EmulatePhase::PrereqCollector;
 BEGIN {
-  $Dist::Zilla::Util::EmulatePhase::PrereqCollector::VERSION = '0.01000515';
+  $Dist::Zilla::Util::EmulatePhase::PrereqCollector::VERSION = '0.01003312';
 }
 #ABSTRACT: A dummy Dist::Zilla to fake a 'prereq' object on.
 
@@ -30,9 +30,18 @@ sub find_files {
   return shift->shadow_zilla->find_files( @_ );
 }
 
+## no critic ( Subroutines::RequireArgUnpacking, Subroutines::ProhibitUnusedPrivateSubroutines, Subroutines::ProtectPrivateSubs )
+sub _share_dir_map {
+  my $self = shift;
+  require Carp;
+  Carp::carp('[Dist::Zilla::Util::EmulatePhase] Call to self->zilla->_share_dir_map should be avoided');
+  return $self->shadow_zilla->_share_dir_map( @_ );
+}
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
+
 __END__
 =pod
 
@@ -42,7 +51,7 @@ Dist::Zilla::Util::EmulatePhase::PrereqCollector - A dummy Dist::Zilla to fake a
 
 =head1 VERSION
 
-version 0.01000515
+version 0.01003312
 
 =head1 METHODS
 
@@ -50,6 +59,13 @@ version 0.01000515
 
 L<< C<Dist::Zilla>'s C<find_files>|Dist::Zilla/find_files >> proxy.
 
+=head2 _share_dir_map
+
+L<< C<Dist::Zilla>'s C<_share_dir_map>|Dist::Zilla/_share_dir_map >> proxy.
+
+B<WARNING>: This method is provided as a temporary workaround and may eventually disappear,
+as the behaviour it is wrapping probably shouldn't be done like this.
+
 =head1 AUTHOR
 
 Kent Fredric <kentnl@cpan.org>
